@@ -1,7 +1,9 @@
 import sys
 import random
+
 random.seed(0)
 import numpy as np
+
 np.random.seed(0)
 import tensorflow as tf
 import onnx_graphsurgeon as gs
@@ -15,15 +17,36 @@ from onnx2tf.utils.common_functions import (
 )
 from onnx2tf.utils.colors import Color
 
+from tensorflow.python.framework import ops
+from tensorflow.python.ops import gen_image_ops
+from tensorflow.python.util import dispatch
+
+
+@dispatch.add_dispatch_support
+def non_max_suppression(boxes,
+                        scores,
+                        max_output_size,
+                        iou_threshold=0.5,
+                        score_threshold=float('-inf'),
+                        name=None):
+    with ops.name_scope(name, 'non_max_suppression'):
+        iou_threshold = ops.convert_to_tensor(iou_threshold, name='iou_threshold')
+        score_threshold = ops.convert_to_tensor(
+            score_threshold, name='score_threshold')
+        selected_indices, num_valid = gen_image_ops.non_max_suppression_v4(boxes, scores, max_output_size,
+                                                                           iou_threshold, score_threshold,
+                                                                           pad_to_max_output_size=False)
+        return selected_indices[:num_valid]
+
 
 @print_node_info
 @inverted_operation_enable_disable
 @get_replacement_parameter
 def make_node(
-    *,
-    graph_node: gs.Node,
-    tf_layers_dict: dict,
-    **kwargs: dict,
+        *,
+        graph_node: gs.Node,
+        tf_layers_dict: dict,
+        **kwargs: dict,
 ):
     """NonMaxSuppression
 
@@ -62,8 +85,6 @@ def make_node(
             graph_node.inputs[2],
             before_op_output_shape_trans,
         )
-        # onnx may contain invalid max_output_boxes_per_class
-        graph_node_input_3 = np.clip(graph_node_input_3, 0, boxes.shape[1])
     graph_node_input_4 = None
     if len(graph_node.inputs) >= 4:
         graph_node_input_4 = get_constant_or_variable(
@@ -83,10 +104,19 @@ def make_node(
     score_threshold = tf_layers_dict[graph_node_input_5.name]['tf_node'] \
         if isinstance(graph_node_input_5, gs.Variable) else graph_node_input_5
 
-    max_output_boxes_per_class = tf.cast(
-        max_output_boxes_per_class,
-        tf.int32,
-    ) if (max_output_boxes_per_class is not None and max_output_boxes_per_class != "") else tf.constant(0, tf.int32)
+    try:
+        max_output_boxes_per_class = tf.cast(
+            max_output_boxes_per_class,
+            tf.int32,
+        )
+    except:
+        max_output_boxes_per_class = tf.constant(0, tf.int32)
+
+    max_output_boxes_per_class = tf.where(
+        condition=max_output_boxes_per_class <= 0,
+        x=tf.shape(boxes)[1],
+        y=max_output_boxes_per_class,
+    )
 
     max_output_boxes_per_class = tf.squeeze(max_output_boxes_per_class) \
         if len(max_output_boxes_per_class.shape) == 1 else max_output_boxes_per_class
@@ -97,7 +127,7 @@ def make_node(
         if len(iou_threshold.shape) == 1 else iou_threshold
 
     score_threshold = score_threshold \
-        if (score_threshold is not None and score_threshold != "") else tf.constant(float('-inf'))
+        if (score_threshold is not None and score_threshold != "") else tf.constant(-np.inf)
     score_threshold = tf.squeeze(score_threshold) \
         if len(score_threshold.shape) == 1 else score_threshold
 
@@ -173,10 +203,10 @@ def make_node(
 
     if num_batches is None:
         print(
-            f'{Color.RED}ERROR:{Color.RESET} '+
-            f'It is not possible to specify a dynamic shape '+
-            f'for the batch size of the input tensor in NonMaxSuppression. '+
-            f'Use the --batch_size option to change the batch size to a fixed size. \n'+
+            f'{Color.RED}ERROR:{Color.RESET} ' +
+            f'It is not possible to specify a dynamic shape ' +
+            f'for the batch size of the input tensor in NonMaxSuppression. ' +
+            f'Use the --batch_size option to change the batch size to a fixed size. \n' +
             f'graph_node.name: {graph_node.name} boxes.shape: {boxes.shape} scores.shape: {scores.shape}'
         )
         sys.exit(1)
@@ -192,13 +222,25 @@ def make_node(
             # get scores in class_j for batch_i only
             tf_scores = tf.squeeze(tf.gather(batch_i_scores, [class_j]), axis=0)
             # get the selected boxes indices
-            selected_indices = tf.image.non_max_suppression(
+
+            selected_indices = non_max_suppression(
                 tf_boxes,
                 tf_scores,
                 max_output_boxes_per_class,
                 iou_threshold,
-                score_threshold,
+                score_threshold
             )
+            if hasattr(score_threshold, 'numpy') and score_threshold.numpy() != -np.inf:
+                selected_scores = tf.gather(
+                    params=tf_scores,
+                    indices=selected_indices,
+                )
+                selected_score_indices = tf.squeeze(
+                    input=tf.where(selected_scores >= score_threshold),
+                    axis=-1,
+                )
+                selected_indices = tf.gather(selected_indices, selected_score_indices)
+
             # add batch and class information into the indices
             output = tf.transpose([tf.cast(selected_indices, dtype=tf.int64)])
             paddings = tf.constant([[0, 0], [1, 0]])
